==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/hu-HU.pl <==
{
  am_pm_abbreviated => [
    "de.",
    "du.",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d., E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y.",
    GyMMM => "G y. MMM",
    GyMMMEd => "G y. MMM d., E",
    GyMMMd => "G y. MMM d.",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "M. d., E",
    MMM => "LLL",
    MMMEd => "MMM d., E",
    "MMMMW-count-one" => "MMM W. 'hete'",
    "MMMMW-count-other" => "MMM W. 'hete'",
    MMMMd => "MMMM d.",
    MMMd => "MMM d.",
    Md => "M. d.",
    d => "d",
    h => "a h",
    hm => "a h:mm",
    hms => "a h:mm:ss",
    hmsv => "a h:mm:ss v",
    hmv => "a h:mm v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y.",
    yM => "y. M.",
    yMEd => "y. MM. dd., E",
    yMMM => "y. MMM",
    yMMMEd => "y. MMM d., E",
    yMMMM => "y. MMMM",
    yMMMd => "y. MMM d.",
    yMd => "y. MM. dd.",
    yQQQ => "y. QQQ",
    yQQQQ => "y. QQQQ",
    "yw-count-one" => "Y w. 'hete'",
    "yw-count-other" => "Y w. 'hete'",
  },
  code => "hu-HU",
  date_format_full => "y. MMMM d., EEEE",
  date_format_long => "y. MMMM d.",
  date_format_medium => "y. MMM d.",
  date_format_short => "y. MM. dd.",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "H",
    "K",
    "Sze",
    "Cs",
    "P",
    "Szo",
    "V",
  ],
  day_format_narrow => [
    "H",
    "K",
    "Sz",
    "Cs",
    "P",
    "Sz",
    "V",
  ],
  day_format_wide => [
    "h\N{U+00e9}tf\N{U+0151}",
    "kedd",
    "szerda",
    "cs\N{U+00fc}t\N{U+00f6}rt\N{U+00f6}k",
    "p\N{U+00e9}ntek",
    "szombat",
    "vas\N{U+00e1}rnap",
  ],
  day_stand_alone_abbreviated => [
    "H",
    "K",
    "Sze",
    "Cs",
    "P",
    "Szo",
    "V",
  ],
  day_stand_alone_narrow => [
    "H",
    "K",
    "Sz",
    "Cs",
    "P",
    "Sz",
    "V",
  ],
  day_stand_alone_wide => [
    "h\N{U+00e9}tf\N{U+0151}",
    "kedd",
    "szerda",
    "cs\N{U+00fc}t\N{U+00f6}rt\N{U+00f6}k",
    "p\N{U+00e9}ntek",
    "szombat",
    "vas\N{U+00e1}rnap",
  ],
  era_abbreviated => [
    "i. e.",
    "i. sz.",
  ],
  era_narrow => [
    "ie.",
    "isz.",
  ],
  era_wide => [
    "Krisztus el\N{U+0151}tt",
    "id\N{U+0151}sz\N{U+00e1}m\N{U+00ed}t\N{U+00e1}sunk szerint",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%Y. %b. %e., %A, %H.%M.%S %Z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%Y. %b. %e., %A, %H.%M.%S %Z",
  glibc_time_12_format => "%H.%M.%S",
  glibc_time_format => "%H.%M.%S",
  language => "Hungarian",
  month_format_abbreviated => [
    "jan.",
    "febr.",
    "m\N{U+00e1}rc.",
    "\N{U+00e1}pr.",
    "m\N{U+00e1}j.",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "aug.",
    "szept.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "\N{U+00c1}",
    "M",
    "J",
    "J",
    "A",
    "Sz",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janu\N{U+00e1}r",
    "febru\N{U+00e1}r",
    "m\N{U+00e1}rcius",
    "\N{U+00e1}prilis",
    "m\N{U+00e1}jus",
    "j\N{U+00fa}nius",
    "j\N{U+00fa}lius",
    "augusztus",
    "szeptember",
    "okt\N{U+00f3}ber",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "febr.",
    "m\N{U+00e1}rc.",
    "\N{U+00e1}pr.",
    "m\N{U+00e1}j.",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "aug.",
    "szept.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "\N{U+00c1}",
    "M",
    "J",
    "J",
    "A",
    "Sz",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janu\N{U+00e1}r",
    "febru\N{U+00e1}r",
    "m\N{U+00e1}rcius",
    "\N{U+00e1}prilis",
    "m\N{U+00e1}jus",
    "j\N{U+00fa}nius",
    "j\N{U+00fa}lius",
    "augusztus",
    "szeptember",
    "okt\N{U+00f3}ber",
    "november",
    "december",
  ],
  name => "Hungarian Hungary",
  native_language => "magyar",
  native_name => "magyar Magyarorsz\N{U+00e1}g",
  native_script => undef,
  native_territory => "Magyarorsz\N{U+00e1}g",
  native_variant => undef,
  quarter_format_abbreviated => [
    "I. n.\N{U+00e9}v",
    "II. n.\N{U+00e9}v",
    "III. n.\N{U+00e9}v",
    "IV. n.\N{U+00e9}v",
  ],
  quarter_format_narrow => [
    "I.",
    "II.",
    "III.",
    "IV.",
  ],
  quarter_format_wide => [
    "I. negyed\N{U+00e9}v",
    "II. negyed\N{U+00e9}v",
    "III. negyed\N{U+00e9}v",
    "IV. negyed\N{U+00e9}v",
  ],
  quarter_stand_alone_abbreviated => [
    "1. n.\N{U+00e9}v",
    "2. n.\N{U+00e9}v",
    "3. n.\N{U+00e9}v",
    "4. n.\N{U+00e9}v",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. negyed\N{U+00e9}v",
    "2. negyed\N{U+00e9}v",
    "3. negyed\N{U+00e9}v",
    "4. negyed\N{U+00e9}v",
  ],
  script => undef,
  territory => "Hungary",
  time_format_full => "H:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/hu-HU.pl <==
{
  am_pm_abbreviated => [
    "de.",
    "du.",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d., E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y.",
    GyMMM => "G y. MMM",
    GyMMMEd => "G y. MMM d., E",
    GyMMMd => "G y. MMM d.",
    GyMd => "GGGGG y. MM. dd.",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "M. d., E",
    MMM => "LLL",
    MMMEd => "MMM d., E",
    "MMMMW-count-one" => "MMMM W. 'hete'",
    "MMMMW-count-other" => "MMMM W. 'hete'",
    MMMMd => "MMMM d.",
    MMMd => "MMM d.",
    Md => "M. d.",
    d => "d",
    h => "a\N{U+202f}h",
    hm => "a\N{U+202f}h:mm",
    hms => "a\N{U+202f}h:mm:ss",
    hmsv => "a\N{U+202f}h:mm:ss v",
    hmv => "a\N{U+202f}h:mm v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y.",
    yM => "y. M.",
    yMEd => "y. MM. dd., E",
    yMMM => "y. MMM",
    yMMMEd => "y. MMM d., E",
    yMMMM => "y. MMMM",
    yMMMd => "y. MMM d.",
    yMd => "y. MM. dd.",
    yQQQ => "y. QQQ",
    yQQQQ => "y. QQQQ",
    "yw-count-one" => "Y w. 'hete'",
    "yw-count-other" => "Y w. 'hete'",
  },
  code => "hu-HU",
  date_format_full => "y. MMMM d., EEEE",
  date_format_long => "y. MMMM d.",
  date_format_medium => "y. MMM d.",
  date_format_short => "y. MM. dd.",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "H",
    "K",
    "Sze",
    "Cs",
    "P",
    "Szo",
    "V",
  ],
  day_format_narrow => [
    "H",
    "K",
    "Sz",
    "Cs",
    "P",
    "Sz",
    "V",
  ],
  day_format_wide => [
    "h\N{U+00e9}tf\N{U+0151}",
    "kedd",
    "szerda",
    "cs\N{U+00fc}t\N{U+00f6}rt\N{U+00f6}k",
    "p\N{U+00e9}ntek",
    "szombat",
    "vas\N{U+00e1}rnap",
  ],
  day_stand_alone_abbreviated => [
    "H",
    "K",
    "Sze",
    "Cs",
    "P",
    "Szo",
    "V",
  ],
  day_stand_alone_narrow => [
    "H",
    "K",
    "Sz",
    "Cs",
    "P",
    "Sz",
    "V",
  ],
  day_stand_alone_wide => [
    "h\N{U+00e9}tf\N{U+0151}",
    "kedd",
    "szerda",
    "cs\N{U+00fc}t\N{U+00f6}rt\N{U+00f6}k",
    "p\N{U+00e9}ntek",
    "szombat",
    "vas\N{U+00e1}rnap",
  ],
  era_abbreviated => [
    "i. e.",
    "i. sz.",
  ],
  era_narrow => [
    "ie.",
    "isz.",
  ],
  era_wide => [
    "Krisztus el\N{U+0151}tt",
    "id\N{U+0151}sz\N{U+00e1}m\N{U+00ed}t\N{U+00e1}sunk szerint",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%Y. %b. %-e., %A, %H:%M:%S %Z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%Y. %b. %-e., %A, %H:%M:%S %Z",
  glibc_time_12_format => "%H:%M:%S",
  glibc_time_format => "%H:%M:%S",
  language => "Hungarian",
  month_format_abbreviated => [
    "jan.",
    "febr.",
    "m\N{U+00e1}rc.",
    "\N{U+00e1}pr.",
    "m\N{U+00e1}j.",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "aug.",
    "szept.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "\N{U+00c1}",
    "M",
    "J",
    "J",
    "A",
    "Sz",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janu\N{U+00e1}r",
    "febru\N{U+00e1}r",
    "m\N{U+00e1}rcius",
    "\N{U+00e1}prilis",
    "m\N{U+00e1}jus",
    "j\N{U+00fa}nius",
    "j\N{U+00fa}lius",
    "augusztus",
    "szeptember",
    "okt\N{U+00f3}ber",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "febr.",
    "m\N{U+00e1}rc.",
    "\N{U+00e1}pr.",
    "m\N{U+00e1}j.",
    "j\N{U+00fa}n.",
    "j\N{U+00fa}l.",
    "aug.",
    "szept.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "\N{U+00c1}",
    "M",
    "J",
    "J",
    "A",
    "Sz",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janu\N{U+00e1}r",
    "febru\N{U+00e1}r",
    "m\N{U+00e1}rcius",
    "\N{U+00e1}prilis",
    "m\N{U+00e1}jus",
    "j\N{U+00fa}nius",
    "j\N{U+00fa}lius",
    "augusztus",
    "szeptember",
    "okt\N{U+00f3}ber",
    "november",
    "december",
  ],
  name => "Hungarian Hungary",
  native_language => "magyar",
  native_name => "magyar Magyarorsz\N{U+00e1}g",
  native_script => undef,
  native_territory => "Magyarorsz\N{U+00e1}g",
  native_variant => undef,
  quarter_format_abbreviated => [
    "I. n.\N{U+00e9}v",
    "II. n.\N{U+00e9}v",
    "III. n.\N{U+00e9}v",
    "IV. n.\N{U+00e9}v",
  ],
  quarter_format_narrow => [
    "I.",
    "II.",
    "III.",
    "IV.",
  ],
  quarter_format_wide => [
    "I. negyed\N{U+00e9}v",
    "II. negyed\N{U+00e9}v",
    "III. negyed\N{U+00e9}v",
    "IV. negyed\N{U+00e9}v",
  ],
  quarter_stand_alone_abbreviated => [
    "1. n.\N{U+00e9}v",
    "2. n.\N{U+00e9}v",
    "3. n.\N{U+00e9}v",
    "4. n.\N{U+00e9}v",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. negyed\N{U+00e9}v",
    "2. negyed\N{U+00e9}v",
    "3. negyed\N{U+00e9}v",
    "4. negyed\N{U+00e9}v",
  ],
  script => undef,
  territory => "Hungary",
  time_format_full => "H:mm:ss zzzz",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 42,
}
